<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns="http://www.w3.org/1999/xhtml">

 <!--


 HTTP EXPLORER
 Copyright (C) 2006 Eddy Ripert

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


 Name.......... Mobile full interface
 Version....... 1.02
 Description... This file transform XML folder generated by the server to a valid xhtml document
 Author........ Eddy Ripert
 Date.......... March, 20th 2006


 -->


 <!--Output type-->

 <xsl:output
	method="xml"
	version="1.0"
	encoding="UTF-8"
	doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" 
	doctype-system="http://www.w3.org/TR/xhtml1/dtD/xhtml1-strict.dtd"
	omit-xml-declaration="yes"
	indent="yes" />


 <!--Global variables : shortcuts-->

 <xsl:variable name="ParentFolderSrc"><xsl:call-template name="getParentFolderSrc" /></xsl:variable>


 <!--Root template-->

 <xsl:template match="/">


  <!--Check document type (folder, message or identification)-->

  <xsl:choose>


   <!--It's a 'folder' document-->

   <xsl:when test="page/document/@type = 'folder'">


    <!--Page head-->

    <html xml:lang="{page/server/language/@type}" lang="{page/server/language/@type}">
     <head>
      <title><xsl:call-template name="getPageTitle" /></title>
      <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
      <link href="/?res=mobile.css" rel="stylesheet" type="text/css" />
      <link href="{page/document/url/@icon}" rel="shortcut icon" />
     </head>
     <body>
      <table id="pghead" cellpadding="0" cellspacing="0">
       <tr>
        <td id="pghead_logocel">
         <div id="pghead_logodiv">
          <img src="/?res=itemicon_small_show_folder.png" alt="" id="pghead_logoimg" />
         </div>
        </td>
        <td>
         <span class="pghead_url"><xsl:call-template name="getCurrentUrl" /></span>
        </td>
       </tr>
      </table>
      <table cellpadding="0" cellspacing="0" class="sectioncontent">


       <!--Section 'folder'-->

       <xsl:if test="(count(page/section[@type='folder']/group/item) > 0) or (count(page/document/url/folder) > 0 and page/server/config/showfolder = 'true')">
        <xsl:call-template name="createCompleteSection">
         <xsl:with-param name="sectionName">folder</xsl:with-param>
        </xsl:call-template>
       </xsl:if>


       <!--Section 'other'-->

       <xsl:if test="count(page/section[@type='other']/group/item) > 0">
        <xsl:call-template name="createCompleteSection">
         <xsl:with-param name="sectionName">other</xsl:with-param>
        </xsl:call-template>
       </xsl:if>


       <!--Section 'sound'-->

       <xsl:if test="count(page/section[@type='sound']/group/item) > 0">
        <xsl:call-template name="createCompleteSection">
         <xsl:with-param name="sectionName">sound</xsl:with-param>
        </xsl:call-template>
       </xsl:if>


       <!--Section 'image'-->

       <xsl:if test="count(page/section[@type='image']/group/item) > 0">
        <xsl:call-template name="createCompleteSection">
         <xsl:with-param name="sectionName">image</xsl:with-param>
        </xsl:call-template>
       </xsl:if>


       <!--Section 'video'-->

       <xsl:if test="count(page/section[@type='video']/group/item) > 0">
        <xsl:call-template name="createCompleteSection">
         <xsl:with-param name="sectionName">video</xsl:with-param>
        </xsl:call-template>
       </xsl:if>


      </table>


      <!--Page end-->

      <p><xsl:call-template name="getAppInfos" /></p>
     </body>
    </html>


   </xsl:when>


   <!--It's a 'message' document-->

   <xsl:when test="page/document/@type = 'message'">
    <html xml:lang="{page/server/language/@type}" lang="{page/server/language/@type}">
     <head>
      <title><xsl:value-of select="page/message/title" /></title>
      <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
      <link href="/?res=mobile.css" rel="stylesheet" type="text/css" />
      <link href="{page/document/url/@icon}" rel="shortcut icon" />
     </head>
     <body>
      <div class="message_div">
       <span class="message_text">
        <xsl:value-of select="page/message/label" />
       </span>
      </div>
     </body>
    </html>
   </xsl:when>


   <!--It's a 'identification' document-->

   <xsl:when test="page/document/@type = 'identification'">
    <html xml:lang="{page/server/language/@type}" lang="{page/server/language/@type}">
     <head>
      <title><xsl:value-of select="page/identification/title" /></title>
      <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
      <link href="/?res=mobile.css" rel="stylesheet" type="text/css" />
      <link href="{page/document/url/@icon}" rel="shortcut icon" />
     </head>
     <body>
      <div class="identification_maincontainer">
       <form method="post" action="">
        <div class="identification_linescontainer"><span class="identification_infofont"><xsl:value-of select="page/server/language/info" /></span></div>
        <div class="identification_linescontainer"><span class="identification_labelfont"><xsl:value-of select="page/server/language/user" /> :</span><input type="text" name="user" id="identification_usertxt" /></div>
        <div class="identification_linescontainer"><span class="identification_labelfont"><xsl:value-of select="page/server/language/password" /> :</span><input type="password" name="password" id="identification_passwordtxt" /></div>
        <div class="identification_linescontainer"><input type="checkbox" name="savepwd" checked="checked" /><span class="identification_savepwdfont"><xsl:value-of select="page/server/language/savepwd" /></span></div>
        <div class="identification_linescontainer"><input type="submit" id="identification_submit" value="{page/server/language/submit}" /></div>
       </form>
      </div>
     </body>
    </html>
   </xsl:when>


  </xsl:choose>


 </xsl:template>


 <!--Get current url (with links)-->

 <xsl:template name="getCurrentUrl">
  <xsl:text>/</xsl:text>
  <xsl:for-each select="page/document/url/folder">
   <a href="{./@src}" class="pghead_url">
    <xsl:value-of select="./@label" />
   </a>
   <xsl:text>/</xsl:text>
  </xsl:for-each>
 </xsl:template>
 

 <!--Get parent folder link-->

 <xsl:template name="getParentFolderSrc">
  <xsl:choose>
   <xsl:when test="count(page/document/url/folder) = 1">
    <xsl:text>/</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="page/document/url/folder[position() = last() - 1]/@src" />
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>


 <!--Get page title-->

 <xsl:template name="getPageTitle">
  <xsl:text>/</xsl:text>
  <xsl:for-each select="page/document/url/folder">
   <xsl:value-of select="./@label" />
   <xsl:text>/</xsl:text>
  </xsl:for-each>
 </xsl:template>


 <!--Get application infos-->

 <xsl:template name="getAppInfos">
  <xsl:value-of select="page/server/version/name" />
  <xsl:text> </xsl:text>
  <xsl:value-of select="page/server/version/num" />
 </xsl:template>


 <!--Create list item-->

 <xsl:template name="createItemList">
  <xsl:param name="Label" />
  <xsl:param name="Src" />
  <xsl:param name="Img" />
  <tr>
   <td class="sncontent_list_namecel">
    <a href="{$Src}"><img src="{$Img}" class="sncontent_list_nameimg" alt="" /></a>
   </td>
   <td>
    <a href="{$Src}" class="linelink"><xsl:value-of select="$Label" /></a>
   </td>
  </tr>
 </xsl:template>


 <!--Create complete section-->

 <xsl:template name="createCompleteSection">
  <xsl:param name="sectionName" />
  <xsl:if test="$ParentFolderSrc != '' and $sectionName = 'folder'">
   <xsl:call-template name="createItemList">
    <xsl:with-param name="Label"><xsl:value-of select="page/server/language/sections/pfolder" /></xsl:with-param>
    <xsl:with-param name="Src"><xsl:value-of select="$ParentFolderSrc" /></xsl:with-param>
    <xsl:with-param name="Img">/?res=itemicon_small_parent.png</xsl:with-param>
   </xsl:call-template>
  </xsl:if>
  <xsl:choose>
   <xsl:when test="$sectionName = 'image'">
    <xsl:for-each select="page/section[@type=$sectionName]/group/item">
     <xsl:call-template name="createItemList">
      <xsl:with-param name="Label"><xsl:value-of select="label" /></xsl:with-param>
      <xsl:with-param name="Src"><xsl:value-of select="src" /></xsl:with-param>
      <xsl:with-param name="Img"><xsl:text>/?res=itemicon_small_show_image.png</xsl:text></xsl:with-param>
     </xsl:call-template>
    </xsl:for-each>
   </xsl:when>
   <xsl:otherwise>
    <xsl:for-each select="page/section[@type=$sectionName]/group/item">
     <xsl:call-template name="createItemList">
      <xsl:with-param name="Label"><xsl:value-of select="label" /></xsl:with-param>
      <xsl:with-param name="Src"><xsl:value-of select="src" /></xsl:with-param>
      <xsl:with-param name="Img"><xsl:value-of select="img" /></xsl:with-param>
     </xsl:call-template>
    </xsl:for-each>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>


</xsl:stylesheet>